Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(25)

Unified Diff: commit-queue/verification/trigger_experimental_try_job.py

Issue 141233003: CQ: do not force HEAD revision for chromium_trybot builders (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « commit-queue/projects.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: commit-queue/verification/trigger_experimental_try_job.py
===================================================================
--- commit-queue/verification/trigger_experimental_try_job.py (revision 247015)
+++ commit-queue/verification/trigger_experimental_try_job.py (working copy)
@@ -13,17 +13,18 @@
class TriggerExperimentalTryJobVerifier(base.Verifier):
name = 'trigger experimental try job'
- def __init__(self, context, percentage, try_job_description):
+ def __init__(self, context, percentage, revision, try_job_description):
super(TriggerExperimentalTryJobVerifier, self).__init__()
self.context = context
self.percentage = percentage
+ self.revision = revision
self.try_job_description = try_job_description
def verify(self, pending):
if random.random() < self.percentage:
try:
self.context.rietveld.trigger_try_jobs(
pending.issue, pending.patchset, 'CQ', False, 'HEAD',
self.try_job_description)
except urllib2.HTTPError as e:
if e.code not in (400, 500, 503):
@@ -13,17 +13,18 @@
try:
self.context.rietveld.trigger_try_jobs(
- pending.issue, pending.patchset, 'CQ', False, 'HEAD',
+ pending.issue, pending.patchset, 'CQ', False, self.revision,
self.try_job_description)
except urllib2.HTTPError as e:
« no previous file with comments | « commit-queue/projects.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698